slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSSetExtraction

Specifies the type of extraction technique to be employed by the eigensolver.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSSetExtraction(EPS eps,EPSExtraction extr)

Logically Collective on eps

### Input Parameters

| eps | - the eigensolver context
| extr | - a known type of extraction

### Options Database Keys

| -eps_ritz | - Rayleigh-Ritz extraction
| -eps_harmonic | - harmonic Ritz extraction
| -eps_harmonic_relative | - harmonic Ritz extraction relative to the eigenvalue
| -eps_harmonic_right | - harmonic Ritz extraction for rightmost eigenvalues
| -eps_harmonic_largest | - harmonic Ritz extraction for largest magnitude (without target)
| -eps_refined | - refined Ritz extraction
| -eps_refined_harmonic | - refined harmonic Ritz extraction

### Notes

Not all eigensolvers support all types of extraction. See the SLEPc Users Manual for details.

By default, a standard Rayleigh-Ritz extraction is used. Other extractions may be useful when computing interior eigenvalues.

Harmonic-type extractions are used in combination with a 'target'.

### See Also

EPSSetTarget(), EPSGetExtraction(), EPSExtraction

### Level

advanced

### Location

src/eps/interface/epsopts.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages